@@ -624,21 +624,21 @@
 		   (else (let ((distance (make-vector (list (+ L2 1) (+ L1 1)) 0)))
 			   (do ((i 0 (+ i 1)))
 			       ((> i L1))
-			     (set! (distance 0 i) i))
+			     (vector-set! distance 0 i i))
 			   (do ((i 0 (+ i 1)))
 			       ((> i L2))
-			     (set! (distance i 0) i))
+			     (vector-set! distance i 0 i))
 			   (do ((i 1 (+ i 1)))
 			       ((> i L2))
 			     (do ((j 1 (+ j 1)))
 				 ((> j L1))
-			       (let ((c1 (+ (distance i (- j 1)) 1))
-				     (c2 (+ (distance (- i 1) j) 1))
-				     (c3 (if (char=? (s2 (- i 1)) (s1 (- j 1)))
-					     (distance (- i 1) (- j 1))
-					     (+ (distance (- i 1) (- j 1)) 1))))
-				 (set! (distance i j) (min c1 c2 c3)))))
-			   (distance L2 L1)))))))
+			       (let ((c1 (+ (vector-ref distance i (- j 1)) 1))
+				     (c2 (+ (vector-ref distance (- i 1) j) 1))
+				     (c3 (if (char=? (string-ref s2 (- i 1)) (string-ref s1 (- j 1)))
+					     (vector-ref distance (- i 1) (- j 1))
+					     (+ (vector-ref distance (- i 1) (- j 1)) 1))))
+				 (vector-set! distance i j (min c1 c2 c3)))))
+			   (vector-ref distance L2 L1)))))))
 	
 	(make-full-let-iterator             ; walk the entire let chain
 	 (lambda* (lt (stop (rootlet)))
